@@ -28,10 +28,10 @@
 #include "account.h"
 #include "private/queuehelper_p.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
-#include <QtCore/QBuffer>
-#include <QtGui/QImage>
+#include <QNetworkRequest>
+#include <QNetworkReply>
+#include <QBuffer>
+#include <QImage>
 
 using namespace KGAPI2;
 
@@ -77,7 +77,7 @@ void ContactCreateJob::Private::processNextContact()
     QStringList headers;
     auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : qAsConst(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
     qCDebug(KGAPIRaw) << headers;
