@@ -90,7 +90,7 @@ class KGAPIDRIVE_EXPORT ChangeFetchJob : public KGAPI2::FetchJob
     explicit ChangeFetchJob(const AccountPtr &account, QObject *parent = nullptr);
     explicit ChangeFetchJob(const QString &changeId, const AccountPtr &account,
                             QObject *parent = nullptr);
-    virtual ~ChangeFetchJob();
+    ~ChangeFetchJob() override;
 
     bool includeSubscribed() const;
     void setIncludeSubscribed(bool includeSubscribed);
