@@ -133,7 +133,7 @@ ParentReferencesList ParentReference::fromJSONFeed(const QByteArray &jsonData)
     const QVariant data = document.toVariant();
     const QVariantMap map = data.toMap();
     if (!map.contains(QStringLiteral("kind")) ||
-            map[QStringLiteral("kind")].toString() != QLatin1String("kind#parentList")) {
+            map[QStringLiteral("kind")].toString() != QLatin1String("drive#parentList")) {
         return ParentReferencesList();
     }
 
